@@ -283,6 +283,20 @@ InputInterface.prototype.setDisabled = function setDisabled(disable) {
     this.inputElement.setDisabled(this._readOnly || disable);
 };
 
+/**
+ * Enables this input interface.
+ */
+InputInterface.prototype.enable = function enable() {
+    this.setDisabled(false);
+};
+
+/**
+ * Disables this input interface.
+ */
+InputInterface.prototype.disable = function disable() {
+    this.setDisabled(true);
+};
+
 /**
  * Inserts this InputInterface into the given DOM Element.
  *
@@ -584,6 +598,10 @@ function ButtonGroupInputInterface(fieldId, fieldDesc) {
         }
         this.wrapperElement.appendChild(label);
     }
+
+    if ('initialValue' in fieldDesc) {
+        this.inputElement.setValue(fieldDesc.initialValue);
+    }
 }
 ButtonGroupInputInterface.prototype = new InputInterface();
 ButtonGroupInputInterface.prototype.insertInto = function insertInto(element) {
@@ -1052,6 +1070,17 @@ ParametrizedTextInputInterface.prototype.getAvailableParameters = function getAv
 };
 
 ParametrizedTextInputInterface.prototype.escapeValue = function escapeValue(value) {
+    switch (typeof value) {
+    case "number":
+    case "boolean":
+        value = value.toString();
+        break;
+    default:
+        if (value == null) {
+            value = "";
+        }
+    }
+
     return value.replace(ParametrizedTextInputInterface.prototype._ESCAPE_RE,
         ParametrizedTextInputInterface.prototype._ESCAPE_FUNC);
 };
