@@ -139,6 +139,22 @@ class IWidgetTester(object):
 
         WebDriverWait(self.testcase.driver, timeout).until(name_changed)
 
+    def wait_loaded(self, timeout=10):
+
+        def iwidget_loaded(driver):
+            iwidget_element = driver.execute_script('''
+                var iwidget = opManager.activeWorkspace.getIWidget(%s);
+                return iwidget.internal_iwidget.loaded ? iwidget.element : null;
+            ''' % self.id)
+
+            if iwidget_element is not None:
+                self.element = iwidget_element
+                return True
+
+            return False
+
+        WebDriverWait(self.testcase.driver, timeout).until(iwidget_loaded)
+
     def remove(self, timeout=30):
 
         old_iwidget_ids = self.testcase.driver.execute_script('return opManager.activeWorkspace.getIWidgets().map(function(iwidget) {return iwidget.id;});')
@@ -302,13 +318,17 @@ class WirecloudRemoteTestCase(object):
 
     def change_main_view(self, view_name):
 
-        if self.get_current_view() != view_name:
-            self.driver.find_element_by_css_selector("#wirecloud_header .menu ." + view_name).click()
+        if self.get_current_view() == view_name:
+            return
 
-            if view_name == 'marketplace':
-                WebDriverWait(self.driver, 30).until(marketplace_loaded)
+        self.driver.find_element_by_css_selector("#wirecloud_header .menu ." + view_name).click()
 
-    def check_popup_menu(self, must_be, must_be_absent=(), must_be_disabled=()):
+        WebDriverWait(self.driver, 30).until(lambda driver: self.get_current_view() == view_name)
+
+        if view_name == 'marketplace':
+            WebDriverWait(self.driver, 30).until(marketplace_loaded)
+
+    def check_popup_menu(self, must_be=(), must_be_absent=(), must_be_disabled=()):
 
         time.sleep(0.1)
 
@@ -496,7 +516,7 @@ class WirecloudRemoteTestCase(object):
 
         return iwidget
 
-    def create_workspace_from_catalogue(self, mashup_name, expect_missing_dependencies=None, install_dependencies=False):
+    def create_workspace_from_catalogue(self, mashup_name, expect_missing_dependencies=None, install_dependencies=False, parameters=None):
 
         self.change_main_view('marketplace')
         self.search_resource(mashup_name)
@@ -522,6 +542,19 @@ class WirecloudRemoteTestCase(object):
             continue_button.click()
 
         self.wait_element_visible_by_xpath("//*[contains(@class, 'window_menu')]//*[text()='New Workspace']").click()
+
+        if parameters is not None:
+
+            save_button = self.wait_element_visible_by_xpath("//*[contains(@class, 'window_menu')]//*[text()='Save']")
+            window_menu = self.driver.find_element_by_css_selector('.window_menu.workspace_preferences')
+
+            for parameter_name, parameter_value in parameters.iteritems():
+                param_input = window_menu.find_element_by_css_selector('input[name="' + parameter_name + '"]')
+                self.fill_form_input(param_input, parameter_value)
+
+            time.sleep(0.2) # Work around saving form data problems
+            save_button.click()
+
         self.wait_wirecloud_ready()
         self.assertTrue(self.get_current_workspace_name().startswith(mashup_name), 'Invalid workspace name after creating workspace from catalogue')
 
@@ -619,6 +652,7 @@ class WirecloudRemoteTestCase(object):
         self.popup_menu_click('Upload to local catalogue')
 
         self.wait_element_visible_by_xpath("//*[contains(@class, 'window_menu')]//*[text()='Accept']")
+
         name_input = self.driver.find_element_by_css_selector('.window_menu .styled_form input[name="name"]')
         self.fill_form_input(name_input, info['name'])
         vendor_input = self.driver.find_element_by_css_selector('.window_menu .styled_form input[name="vendor"]')
@@ -628,6 +662,21 @@ class WirecloudRemoteTestCase(object):
         email_input = self.driver.find_element_by_css_selector('.window_menu .styled_form input[name="email"]')
         self.fill_form_input(email_input, info['email'])
 
+        if info.get('readOnlyWidgets', False) is True or info.get('readOnlyConnectables', False) is True:
+            tabs = self.driver.find_elements_by_css_selector('.styled_form .notebook .tab_wrapper .tab')
+            for tab in tabs:
+                span = tab.find_element_by_css_selector('span')
+                if span.text == 'Advanced':
+                    tab.click()
+
+        if info.get('readOnlyWidgets', False) is True:
+            boolean_input = self.driver.find_element_by_css_selector('.window_menu [name="readOnlyWidgets"]')
+            boolean_input.click()
+
+        if info.get('readOnlyConnectables', False) is True:
+            boolean_input = self.driver.find_element_by_css_selector('.window_menu [name="readOnlyConnectables"]')
+            boolean_input.click()
+
         self.driver.find_element_by_xpath("//*[contains(@class, 'window_menu')]//*[text()='Accept']").click()
         self.wait_wirecloud_ready()
 
@@ -749,7 +798,7 @@ class WirecloudRemoteTestCase(object):
 
         self.search_resource(resource_name)
         resource = self.search_in_catalogue_results(resource_name)
-        self.scroll_and_click(resource.find_element_by_css_selector('.click_for_details'))
+        self.scroll_and_click(resource)
 
         WebDriverWait(self.driver, timeout).until(lambda driver: catalogue_base_element.find_element_by_css_selector('.advanced_operations').is_displayed())
         time.sleep(0.1)
@@ -776,7 +825,7 @@ class WirecloudRemoteTestCase(object):
 
         self.search_resource(resource_name)
         resource = self.search_in_catalogue_results(resource_name)
-        self.scroll_and_click(resource.find_element_by_css_selector('.click_for_details'))
+        self.scroll_and_click(resource)
 
         WebDriverWait(self.driver, timeout).until(lambda driver: catalogue_base_element.find_element_by_css_selector('.advanced_operations').is_displayed())
         time.sleep(0.1)
