@@ -76,7 +76,11 @@ class RDFTemplateParser(object):
                 self._info['type'] = 'operator'
                 break
             else:
-                self._info['type'] = 'mashup'
+                for t in self._graph.subjects(RDF['type'], WIRE_M['Mashup']):
+                    self._info['type'] = 'mashup'
+                    break
+                else:
+                    raise TemplateParseException('RDF document does not describe a widget, operator or mashup resource')
 
         self._parse_basic_info()
 
@@ -459,15 +463,16 @@ class RDFTemplateParser(object):
 
         self._info['preferences'] = preferences
 
-        params = {}
-        for param in self._graph.objects(self._rootURI, WIRE_M['hasWorkspaceParam']):
-            params[self._get_field(DCTERMS, 'title', param)] = {
+        ordered_params = sorted(self._graph.objects(self._rootURI, WIRE_M['hasMashupParam']), key=lambda raw_param: possible_int(self._get_field(WIRE, 'index', raw_param, required=False)))
+        self._info['params'] = []
+        for param in ordered_params:
+            self._info['params'].append({
+                'name': self._get_field(DCTERMS, 'title', param),
                 'label': self._get_field(RDFS, 'label', param),
                 'type': self._get_field(WIRE, 'type', param),
-            }
-        self._info['params'] = params
+            })
 
-        ordered_tabs = sorted(self._graph.objects(self._rootURI, WIRE_M['hasTab']), key=lambda raw_tab: int(self._get_field(WIRE, 'index', raw_tab, required=False)))
+        ordered_tabs = sorted(self._graph.objects(self._rootURI, WIRE_M['hasTab']), key=lambda raw_tab: possible_int(self._get_field(WIRE, 'index', raw_tab, required=False)))
 
         tabs = []
         for tab in ordered_tabs:
@@ -491,6 +496,7 @@ class RDFTemplateParser(object):
                     'vendor': self._get_field(FOAF, 'name', vendor),
                     'version': self._get_field(USDL, 'versionInfo', resource),
                     'title': self._get_field(DCTERMS, 'title', resource),
+                    'readonly': self._get_field(WIRE_M, 'readonly', resource, required=False).lower() == 'true',
                     'properties': {},
                     'preferences': {},
                     'position': {
