@@ -123,6 +123,17 @@ def write_wiring_views_graph(graph, wiring, template_info):
                 graph.add((target_element, WIRE['index'], rdflib.Literal(str(index))))
 
 
+def write_mashup_params(graph, resource_uri, template_info):
+
+    if len(template_info['params']) > 0:
+        for param_index, param in enumerate(template_info['params']):
+            param_node = rdflib.BNode()
+            graph.add((param_node, DCTERMS['title'], rdflib.Literal(param['name'])))
+            graph.add((param_node, WIRE['index'], rdflib.Literal(str(param_index))))
+            graph.add((param_node, RDFS['label'], rdflib.Literal(param['label'])))
+            graph.add((param_node, WIRE['type'], rdflib.Literal(param['type'])))
+            graph.add((resource_uri, WIRE_M['hasMashupParam'], param_node))
+
 def write_mashup_resources_graph(graph, resource_uri, template_info):
 
     # Tabs & resources
@@ -154,7 +165,7 @@ def write_mashup_resources_graph(graph, resource_uri, template_info):
             graph.add((resource, DCTERMS['title'], rdflib.Literal(iwidget['title'])))
 
             if iwidget.get('readonly', False):
-                graph.add((resource, WIRE['readonly'], rdflib.Literal('true')))
+                graph.add((resource, WIRE_M['readonly'], rdflib.Literal('true')))
 
             # iWidget position
             pos = rdflib.BNode()
@@ -301,6 +312,10 @@ def build_rdf_graph(template_info):
     if template_info['type'] == 'mashup':
         write_mashup_resources_graph(graph, resource_uri, template_info)
 
+    # Params
+    if template_info['type'] == 'mashup':
+        write_mashup_params(graph, resource_uri, template_info)
+
     # Create wiring
     wiring = rdflib.BNode()
     graph.add((wiring, rdflib.RDF.type, WIRE['PlatformWiring']))
