@@ -223,13 +223,13 @@ class WirecloudCorePlugin(WirecloudPlugin):
             'js/wirecloud/ui/Draggable.js',
             'js/wirecloud/ui/Theme.js',
             'js/wirecloud/WirecloudCatalogue.js',
-            'js/log/LogManager.js',
             'js/wirecloud/LocalCatalogue.js',
             'js/wirecloud/wiring/Endpoint.js',
             'js/wirecloud/wiring/EndpointException.js',
             'js/wirecloud/wiring/SourceEndpoint.js',
             'js/wirecloud/wiring/TargetEndpoint.js',
             'js/wirecloud/wiring/OperatorFactory.js',
+            'js/wirecloud/wiring/OperatorLogManager.js',
             'js/wirecloud/wiring/OperatorUserPref.js',
             'js/wirecloud/wiring/Operator.js',
             'js/wirecloud/wiring/OperatorMeta.js',
@@ -286,7 +286,6 @@ class WirecloudCorePlugin(WirecloudPlugin):
                 "catalogue_main_resource_details_template": "wirecloud/catalogue/main_resource_details.html",
                 "catalogue_resource_details_template": "wirecloud/catalogue/resource_details.html",
                 "wirecloud_catalogue_publish_interface": "wirecloud/catalogue/developers.html",
-                "wirecloud_logs_template": "wirecloud/logs.html",
             }
         else:
             return {}
