@@ -99,14 +99,12 @@ def _populate_variables_values_cache(workspace, user, key, forced_values=None):
             entry['hidden'] = fv_entry.get('hidden', False)
 
         else:
-            if not var_value.variable.vardef.secure:
-                entry['value'] = var_value.get_variable_value()
-            else:
-                entry['value'] = var_value.value
+            entry['value'] = var_value.value
 
             entry['readonly'] = False
             entry['hidden'] = False
 
+        entry['type'] = var_value.variable.vardef.type
         entry['secure'] = var_value.variable.vardef.secure
 
         values_by_varname[variwidget][varname] = entry
@@ -158,9 +156,14 @@ def get_variable_value_from_varname(user, iwidget, var_name):
 
     entry = values['by_varname'][iwidget_id][var_name]
     if entry['secure'] == True:
-        return decrypt_value(entry['value'])
+        value = decrypt_value(entry['value'])
     else:
-        return entry['value']
+        value = entry['value']
+
+    if entry['type'] == 'B':
+        value = value.lower() == 'true'
+
+    return value
 
 
 def _invalidate_cached_variable_values(workspace, user=None):
@@ -234,7 +237,12 @@ class VariableValueCacheManager():
             data_ret['value'] = ''
             data_ret['secure'] = True
         else:
-            data_ret['value'] = entry['value']
+            value = entry['value']
+
+            if entry['type'] == 'B':
+                value = value.lower() == 'true'
+
+            data_ret['value'] = value
 
         data_ret['readonly'] = entry['readonly']
         data_ret['hidden'] = entry['hidden']
@@ -300,15 +308,19 @@ def process_forced_values(workspace, user, concept_values, preferences):
     except:
         forced_values = {
             'iwidget': {},
+            'ioperator': {},
         }
 
     if not 'extra_prefs' in forced_values:
         forced_values['extra_prefs'] = {}
 
+    if not 'ioperator' in forced_values:
+        forced_values['ioperator'] = {}
+
     if not 'iwidget' in forced_values:
         forced_values['iwidget'] = {}
 
-    if len(forced_values['iwidget']) == 0:
+    if len(forced_values['iwidget']) == 0 and len(forced_values['ioperator']) == 0:
         forced_values['empty_params'] = []
         return forced_values
 
@@ -330,6 +342,12 @@ def process_forced_values(workspace, user, concept_values, preferences):
         for var_name in values:
             collection[key][var_name]['value'] = processor.process(values[var_name]['value'])
 
+    collection = forced_values['ioperator']
+    for key in collection:
+        values = collection[key]
+        for var_name in values:
+            collection[key][var_name]['value'] = processor.process(values[var_name]['value'])
+
     return forced_values
 
 
@@ -383,6 +401,9 @@ def _get_global_workspace_data(workspaceDAO, user):
         tab['iwidgets'] = iwidget_data
 
     data_ret['wiring'] = json.loads(workspaceDAO.wiringStatus)
+    for forced_operator_id, forced_preferences in forced_values['ioperator'].iteritems():
+        for forced_pref_name, forced_preference in forced_preferences.iteritems():
+            data_ret['wiring']['operators'][forced_operator_id]['preferences'][forced_pref_name]['value'] = forced_preference['value']
 
     # Params
     last_published_workspace = PublishedWorkspace.objects.filter(workspace=workspaceDAO).order_by('-pk')
