@@ -22,16 +22,14 @@ from shutil import rmtree
 from tempfile import mkdtemp
 
 from django.contrib.auth.models import User, Group
-from django.core.cache import cache
 from django.core.urlresolvers import reverse
-from django.test import TransactionTestCase, Client
+from django.test import Client
 
 from wirecloud.catalogue import utils as catalogue
 from wirecloud.catalogue.models import CatalogueResource
 import wirecloud.commons
-from wirecloud.commons.utils import downloader
 from wirecloud.commons.utils.template import TemplateParser, TemplateParseException
-from wirecloud.commons.utils.testcases import cleartree, FakeDownloader, LocalizedTestCase, WirecloudSeleniumTestCase
+from wirecloud.commons.utils.testcases import cleartree, DynamicWebServer, WirecloudSeleniumTestCase, WirecloudTestCase
 from wirecloud.commons.utils.wgt import WgtDeployer, WgtFile
 from wirecloud.platform.localcatalogue.utils import install_resource, install_resource_to_user
 import wirecloud.platform.widget.utils
@@ -45,20 +43,19 @@ __test__ = False
 BASIC_HTML_GADGET_CODE = "<html><body><p>widget code</p></body></html>"
 
 
-class LocalCatalogueTestCase(LocalizedTestCase):
+class LocalCatalogueTestCase(WirecloudTestCase):
 
     fixtures = ('test_data',)
+    servers = {
+        'http': {
+            'example.com': DynamicWebServer(),
+        }
+    }
+    tags = ('localcatalogue',)
 
     def setUp(self):
         super(LocalCatalogueTestCase, self).setUp()
-        self._original_function = downloader.download_http_content
-        downloader.download_http_content = FakeDownloader()
         self.user = User.objects.get(username='test')
-        cache.clear()
-
-    def tearDown(self):
-        super(LocalCatalogueTestCase, self).tearDown()
-        downloader.download_http_content = self._original_function
 
     def read_template(self, *template):
         f = open(os.path.join(os.path.dirname(__file__), 'test-data', *template))
@@ -94,8 +91,8 @@ class LocalCatalogueTestCase(LocalizedTestCase):
         template_uri = "http://example.com/path/widget.xml"
         template = self.read_template('template1.xml')
 
-        downloader.download_http_content.set_response(template_uri, template)
-        downloader.download_http_content.set_response('http://example.com/path/test.html', BASIC_HTML_GADGET_CODE)
+        self.network._servers['http']['example.com'].add_response('GET', '/path/widget.xml', {'content': template})
+        self.network._servers['http']['example.com'].add_response('GET', '/path/test.html', {'content': BASIC_HTML_GADGET_CODE})
         resource = install_resource_to_user(self.user, file_contents=template, templateURL=template_uri)
 
         self.assertEqual(resource.vendor, 'Wirecloud')
@@ -111,8 +108,8 @@ class LocalCatalogueTestCase(LocalizedTestCase):
         template_uri = "http://example.com/path/widget.xml"
         template = self.read_template('old-template.xml')
 
-        downloader.download_http_content.set_response(template_uri, template)
-        downloader.download_http_content.set_response('http://example.com/path/test.html', BASIC_HTML_GADGET_CODE)
+        self.network._servers['http']['example.com'].add_response('GET', '/path/widget.xml', {'content': template})
+        self.network._servers['http']['example.com'].add_response('GET', '/path/test.html', {'content': BASIC_HTML_GADGET_CODE})
         resource = install_resource(template, template_uri, self.user, False)
 
         self.check_basic_widget_info(resource)
@@ -126,8 +123,8 @@ class LocalCatalogueTestCase(LocalizedTestCase):
         self.assertIn('requirements', data)
         self.assertItemsEqual(data['requirements'], ({'type': 'feature', 'name': 'Wirecloud'},))
 
-        downloader.download_http_content.set_response(template_uri, template)
-        downloader.download_http_content.set_response('http://example.com/path/test.html', BASIC_HTML_GADGET_CODE)
+        self.network._servers['http']['example.com'].add_response('GET', '/path/widget.rdf', {'content': template})
+        self.network._servers['http']['example.com'].add_response('GET', '/path/test.html', {'content': BASIC_HTML_GADGET_CODE})
         resource = install_resource(template, template_uri, self.user, False)
 
         self.check_basic_widget_info(resource)
@@ -181,8 +178,8 @@ class LocalCatalogueTestCase(LocalizedTestCase):
             'version': '0.1',
         }
 
-        downloader.download_http_content.set_response(template_uri, template)
-        downloader.download_http_content.set_response('http://example.com/path/test.html', BASIC_HTML_GADGET_CODE)
+        self.network._servers['http']['example.com'].add_response('GET', '/path/widget.xml', {'content': template})
+        self.network._servers['http']['example.com'].add_response('GET', '/path/test.html', {'content': BASIC_HTML_GADGET_CODE})
         resource = install_resource_to_user(self.user, file_contents=template, templateURL=template_uri)
         resource_pk = resource.pk
         xhtml_pk = resource.widget.pk
@@ -198,7 +195,7 @@ class LocalCatalogueTestCase(LocalizedTestCase):
         self.assertRaises(CatalogueResource.DoesNotExist, CatalogueResource.objects.get, pk=resource_pk)
 
         # Use a different xhtml code
-        downloader.download_http_content.set_response('http://example.com/path/test.html', 'cache')
+        self.network._servers['http']['example.com'].add_response('GET', '/path/test.html', {'content': 'cache'})
         install_resource_to_user(self.user, file_contents=template, templateURL=template_uri)
 
         response = client.get(reverse('wirecloud.widget_code_entry', kwargs=widget_id))
@@ -211,8 +208,8 @@ class LocalCatalogueTestCase(LocalizedTestCase):
         template_uri = "http://example.com/path/widget.xml"
         template = self.read_template('template3.xml')
 
-        downloader.download_http_content.set_response(template_uri, template)
-        downloader.download_http_content.set_response('http://example.com/path/test.html', BASIC_HTML_GADGET_CODE)
+        self.network._servers['http']['example.com'].add_response('GET', '/path/widget.xml', {'content': template})
+        self.network._servers['http']['example.com'].add_response('GET', '/path/test.html', {'content': BASIC_HTML_GADGET_CODE})
         self.assertRaises(TemplateParseException, install_resource, template, template_uri, self.user, False)
         self.assertRaises(CatalogueResource.DoesNotExist, CatalogueResource.objects.get, vendor='Wirecloud', short_name='test', version='0.1')
 
@@ -220,8 +217,8 @@ class LocalCatalogueTestCase(LocalizedTestCase):
         template_uri = "http://example.com/path/widget.xml"
         template = self.read_template('template4.xml')
 
-        downloader.download_http_content.set_response(template_uri, template)
-        downloader.download_http_content.set_response('http://example.com/path/test.html', BASIC_HTML_GADGET_CODE)
+        self.network._servers['http']['example.com'].add_response('GET', '/path/widget.xml', {'content': template})
+        self.network._servers['http']['example.com'].add_response('GET', '/path/test.html', {'content': BASIC_HTML_GADGET_CODE})
         self.assertRaises(TemplateParseException, install_resource, template, template_uri, self.user, False)
         self.assertRaises(CatalogueResource.DoesNotExist, CatalogueResource.objects.get, vendor='Wirecloud', short_name='test', version='0.1')
 
@@ -230,8 +227,8 @@ class LocalCatalogueTestCase(LocalizedTestCase):
         template_uri = "http://example.com/path/widget.xml"
         template = self.read_template('template1.xml')
 
-        downloader.download_http_content.set_response(template_uri, template)
-        downloader.download_http_content.set_response('http://example.com/path/test.html', BASIC_HTML_GADGET_CODE)
+        self.network._servers['http']['example.com'].add_response('GET', '/path/widget.xml', {'content': template})
+        self.network._servers['http']['example.com'].add_response('GET', '/path/test.html', {'content': BASIC_HTML_GADGET_CODE})
         resource = install_resource_to_user(self.user, file_contents=template, templateURL=template_uri)
 
         self.changeLanguage('es')
@@ -261,8 +258,8 @@ class LocalCatalogueTestCase(LocalizedTestCase):
         template_uri = "http://example.com/path/widget.xml"
         template = self.read_template('template2.xml')
 
-        downloader.download_http_content.set_response(template_uri, template)
-        downloader.download_http_content.set_response('http://example.com/path/test.html', BASIC_HTML_GADGET_CODE)
+        self.network._servers['http']['example.com'].add_response('GET', '/path/widget.xml', {'content': template})
+        self.network._servers['http']['example.com'].add_response('GET', '/path/test.html', {'content': BASIC_HTML_GADGET_CODE})
         resource = install_resource(template, template_uri, self.user, False)
 
         data = resource.get_processed_info()
@@ -283,20 +280,20 @@ class LocalCatalogueTestCase(LocalizedTestCase):
 
     def test_widgets_with_invalid_format(self):
         template_uri = "http://example.com/path/widget.xml"
-        downloader.download_http_content.set_response('http://example.com/path/test.html', BASIC_HTML_GADGET_CODE)
+        self.network._servers['http']['example.com'].add_response('GET', '/path/test.html', {'content': BASIC_HTML_GADGET_CODE})
 
         template = self.read_template('template5.xml')
-        downloader.download_http_content.set_response(template_uri, template)
+        self.network._servers['http']['example.com'].add_response('GET', '/path/widget.xml', {'content': template})
         self.assertRaises(TemplateParseException, install_resource, template, template_uri, self.user, False)
         self.assertRaises(CatalogueResource.DoesNotExist, CatalogueResource.objects.get, vendor='Wirecloud', short_name='test', version='0.1')
 
         template = self.read_template('template6.xml')
-        downloader.download_http_content.set_response(template_uri, template)
+        self.network._servers['http']['example.com'].add_response('GET', '/path/widget.xml', {'content': template})
         self.assertRaises(TemplateParseException, install_resource, template, template_uri, self.user, False)
         self.assertRaises(CatalogueResource.DoesNotExist, CatalogueResource.objects.get, vendor='Wirecloud', short_name='test', version='0.1')
 
         template = self.read_template('template7.xml')
-        downloader.download_http_content.set_response(template_uri, template)
+        self.network._servers['http']['example.com'].add_response('GET', '/path/widget.xml', {'content': template})
         self.assertRaises(TemplateParseException, install_resource, template, template_uri, self.user, False)
         self.assertRaises(CatalogueResource.DoesNotExist, CatalogueResource.objects.get, vendor='Wirecloud', short_name='test', version='0.1')
 
@@ -310,7 +307,7 @@ class LocalCatalogueTestCase(LocalizedTestCase):
         self.assertIn('requirements', data)
         self.assertItemsEqual(data['requirements'], ({'type': 'feature', 'name': 'nonexistent-feature'}, {'type': 'feature', 'name': 'Wirecloud'},))
 
-        downloader.download_http_content.set_response(template_uri, template)
+        self.network._servers['http']['example.com'].add_response('GET', '/path/widget.xml', {'content': template})
         self.assertRaises(Exception, install_resource, template, template_uri, self.user, False)
         self.assertRaises(Widget.DoesNotExist, Widget.objects.get, resource__vendor='Example', resource__short_name='test', resource__version='0.1')
 
@@ -324,27 +321,27 @@ class LocalCatalogueTestCase(LocalizedTestCase):
         self.assertIn('requirements', data)
         self.assertItemsEqual(data['requirements'], ({'type': 'feature', 'name': 'nonexistent-feature'}, {'type': 'feature', 'name': 'Wirecloud'},))
 
-        downloader.download_http_content.set_response(template_uri, template)
+        self.network._servers['http']['example.com'].add_response('GET', '/path/widget.xml', {'content': template})
         self.assertRaises(Exception, install_resource, template, template_uri, self.user, False)
         self.assertRaises(Widget.DoesNotExist, Widget.objects.get, resource__vendor='Example', resource__short_name='test', resource__version='0.1')
 
     def test_widgets_with_invalid_format_rdf(self):
         template_uri = "http://example.com/path/widget.rdf"
-        downloader.download_http_content.set_response('http://example.com/path/test.html', BASIC_HTML_GADGET_CODE)
+        self.network._servers['http']['example.com'].add_response('GET', '/path/test.html', {'content': BASIC_HTML_GADGET_CODE})
 
         template = self.read_template('template5.rdf')
-        downloader.download_http_content.set_response(template_uri, template)
+        self.network._servers['http']['example.com'].add_response('GET', '/path/widget.rdf', {'content': template})
         self.assertRaises(TemplateParseException, install_resource, template, template_uri, self.user, False)
 
         template = self.read_template('template6.rdf')
-        downloader.download_http_content.set_response(template_uri, template)
+        self.network._servers['http']['example.com'].add_response('GET', '/path/widget.rdf', {'content': template})
         self.assertRaises(TemplateParseException, install_resource, template, template_uri, self.user, False)
 
     def test_basic_mashup(self):
 
         template_uri = "http://example.com/path/mashup.xml"
         template = self.read_template('..', '..', 'workspace', 'test-data', 'wt1.xml')
-        downloader.download_http_content.set_response(template_uri, template)
+        self.network._servers['http']['example.com'].add_response('GET', '/path/mashup.xml', {'content': template})
         resource = install_resource_to_user(self.user, file_contents=template, templateURL=template_uri)
 
         self.assertEqual(resource.vendor, 'Wirecloud Test Suite')
@@ -356,7 +353,7 @@ class LocalCatalogueTestCase(LocalizedTestCase):
 
         template_uri = "http://example.com/path/mashup.rdf"
         template = self.read_template('..', '..', 'workspace', 'test-data', 'wt1.rdf')
-        downloader.download_http_content.set_response(template_uri, template)
+        self.network._servers['http']['example.com'].add_response('GET', '/path/mashup.rdf', {'content': template})
         resource = install_resource_to_user(self.user, file_contents=template, templateURL=template_uri)
 
         self.assertEqual(resource.vendor, 'Wirecloud Test Suite')
@@ -365,7 +362,9 @@ class LocalCatalogueTestCase(LocalizedTestCase):
         self.assertTrue(resource.is_available_for(self.user))
 
 
-class PackagedResourcesTestCase(TransactionTestCase):
+class PackagedResourcesTestCase(WirecloudTestCase):
+
+    tags = ('localcatalogue',)
 
     @classmethod
     def setUpClass(cls):
@@ -457,6 +456,8 @@ class PackagedResourcesTestCase(TransactionTestCase):
 
 class LocalCatalogueSeleniumTests(WirecloudSeleniumTestCase):
 
+    tags = ('localcatalogue',)
+
     def test_public_resources(self):
 
         self.login()
