@@ -18,6 +18,7 @@
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
 
+import errno
 import json
 from cStringIO import StringIO
 import os
@@ -147,6 +148,13 @@ class ResourceCollection(Resource):
 
             resource = install_resource_to_user(request.user, file_contents=file_contents, templateURL=templateURL, packaged=packaged, raise_conflicts=force_create)
 
+        except OSError, e:
+
+            if e.errno == errno.EACCES:
+                return build_error_response(request, 500, _('Error writing the resource into the filesystem. Please, contact the server administrator.'))
+            else:
+                raise
+
         except (TemplateParseException, InvalidContents), e:
 
             return build_error_response(request, 400, unicode(e))
@@ -225,4 +233,13 @@ class ResourceDescriptionEntry(Resource):
             return HttpResponse(status=403)
 
         resource_info = resource.get_processed_info(request)
+        if request.GET.get('include_wgt_files', '').lower() == 'true':
+            if resource.fromWGT:
+                base_dir = catalogue_utils.wgt_deployer.get_base_dir(resource.vendor, resource.short_name, resource.version)
+                wgt_file = zipfile.ZipFile(os.path.join(base_dir, resource.template_uri))
+                resource_info['wgt_files'] = [filename for filename in wgt_file.namelist() if filename[-1] != '/']
+                wgt_file.close()
+            else:
+                resource_info['wgt_files'] = ()
+
         return HttpResponse(json.dumps(resource_info), mimetype='application/json; charset=UTF-8')
