@@ -19,7 +19,7 @@
  *
  */
 
-/*global CatalogueResource, CatalogueSearchView, Constants, Event, gettext, interpolate, LayoutManagerFactory, LogManagerFactory, OpManagerFactory, Wirecloud, StyledElements*/
+/*global CatalogueResource, CatalogueSearchView, Constants, Event, gettext, interpolate, LayoutManagerFactory, OpManagerFactory, Wirecloud, StyledElements*/
 
 (function () {
 
@@ -51,6 +51,16 @@
         };
         this.viewsByName.search.init();
 
+        this.alternatives.addEventListener('postTransition', function (alternatives, out_alternative) {
+            var new_status = options.catalogue.buildStateData();
+
+            if (out_alternative === this.viewsByName.initial) {
+                HistoryManager.replaceState(new_status);
+            } else {
+                HistoryManager.pushState(new_status);
+            }
+        }.bind(this));
+
         this.addEventListener('show', function () {
             if (this.alternatives.getCurrentAlternative() === this.viewsByName.initial) {
                 this.changeCurrentView('search');
@@ -145,7 +155,7 @@
                 }.bind(this),
                 onFailure: function (msg) {
                     LayoutManagerFactory.getInstance().showMessageMenu(msg, Constants.Logging.ERROR_MSG);
-                    LogManagerFactory.getInstance().log(msg);
+                    Wirecloud.GlobalLogManager.log(msg);
                 },
                 onComplete: function () {
                     LayoutManagerFactory.getInstance()._notifyPlatformReady();
@@ -176,7 +186,7 @@
                 }.bind(this),
                 onFailure: function (msg) {
                     LayoutManagerFactory.getInstance().showMessageMenu(msg, Constants.Logging.ERROR_MSG);
-                    LogManagerFactory.getInstance().log(msg);
+                    Wirecloud.GlobalLogManager.log(msg);
                 },
                 onComplete: function () {
                     LayoutManagerFactory.getInstance()._notifyPlatformReady();
