@@ -20,7 +20,7 @@
  */
 
 /*jslint white: true, onevar: false, undef: true, nomen: false, eqeqeq: true, plusplus: false, bitwise: true, regexp: true, newcap: true, immed: true, strict: false, forin: true, sub: true*/
-/*global gettext, Constants, DragboardLayout, DragboardPosition, IWidget, LayoutManagerFactory, LogManagerFactory, MultiValuedSize*/
+/*global gettext, Constants, DragboardLayout, DragboardPosition, IWidget, LayoutManagerFactory, MultiValuedSize*/
 
 /////////////////////////////////////
 // FreeLayout
@@ -170,7 +170,7 @@ FreeLayout.prototype.initializeMove = function (iwidget, draggable) {
     // Check for pendings moves
     if (this.iwidgetToMove !== null) {
         msg = gettext("There was a pending move that was cancelled because initializedMove function was called before it was finished.");
-        LogManagerFactory.getInstance().log(msg, Constants.WARN_MSG);
+        Wirecloud.GlobalLogManager.log(msg, Constants.WARN_MSG);
         this.cancelMove();
     }
 
@@ -186,7 +186,7 @@ FreeLayout.prototype.initializeMove = function (iwidget, draggable) {
 FreeLayout.prototype.moveTemporally = function (x, y) {
     if (!(this.iwidgetToMove instanceof IWidget)) {
         var msg = gettext("Dragboard: You must call initializeMove function before calling to this function (moveTemporally).");
-        LogManagerFactory.getInstance().log(msg, Constants.WARN_MSG);
+        Wirecloud.GlobalLogManager.log(msg, Constants.WARN_MSG);
         return;
     }
 
@@ -197,7 +197,7 @@ FreeLayout.prototype.moveTemporally = function (x, y) {
 FreeLayout.prototype.acceptMove = function () {
     if (!(this.iwidgetToMove instanceof IWidget)) {
         var msg = gettext("Function acceptMove called when there is not an started iwidget move.");
-        LogManagerFactory.getInstance().log(msg, Constants.WARN_MSG);
+        Wirecloud.GlobalLogManager.log(msg, Constants.WARN_MSG);
         return;
     }
 
@@ -224,7 +224,7 @@ FreeLayout.prototype.cancelMove = function () {
 
     if (!(this.iwidgetToMove instanceof IWidget)) {
         msg = gettext("Trying to cancel an inexistant temporal move.");
-        LogManagerFactory.getInstance().log(msg, Constants.WARN_MSG);
+        Wirecloud.GlobalLogManager.log(msg, Constants.WARN_MSG);
         return;
     }
 
