@@ -33,6 +33,11 @@
             type = 'select';
         }
 
+        // the value option is only used on the server side
+        if ('value' in options) {
+            delete options.value;
+        }
+
         Object.defineProperty(this, 'varName', {value: varName});
         Object.defineProperty(this, 'type', {value: type});
         Object.defineProperty(this, 'label', {value: options.label});
@@ -71,7 +76,7 @@
 
         desc = EzWebExt.merge(this.options, {
             'type': this.type,
-            'disabled': variable.readOnly,
+            'initiallyDisabled': variable.readOnly,
             'initialValue': variable.get(),
             'required': false
         });
