@@ -19,7 +19,7 @@
  *
  */
 
-/*global gettext, interpolate, IWidget, LogManagerFactory, wEvent, wSlot, Wirecloud*/
+/*global gettext, interpolate, Wirecloud*/
 
 (function () {
 
@@ -90,7 +90,7 @@
 
         if (iwidget.id in this.connectablesByWidget) {
             var msg = gettext("Error adding iWidget into the wiring module of the workspace: Widget instance already exists.");
-            LogManagerFactory.getInstance().log(msg);
+            Wirecloud.GlobalLogManager.log(msg);
             return;
         }
 
@@ -103,7 +103,7 @@
 
         if (!(iwidget.id in this.connectablesByWidget)) {
             var msg = gettext("Error: trying to remove an inexistant iWidget from the wiring module.");
-            LogManagerFactory.getInstance().log(msg);
+            Wirecloud.GlobalLogManager.log(msg);
             return;
         }
 
@@ -217,6 +217,13 @@
             targetConnectable = findConnectable.call(this, connection.target);
             if (sourceConnectable != null && targetConnectable != null) {
                 sourceConnectable.connect(targetConnectable);
+            } else {
+                msg = gettext('The connection between %(source)s and %(target)s could be established');
+                msg = interpolate(msg, {
+                    source: JSON.stringify(connection.source),
+                    target: JSON.stringify(connection.target)
+                }, true);
+                this.events.error.dispatch(msg);
             }
         }
 
@@ -253,36 +260,6 @@
         this.workspace = null;
     };
 
-    Wiring.prototype.getOperatorPrefValue = function getOperatorPrefValue(iOperator, key) {
-        var entry;
-
-        if (iOperator instanceof Wirecloud.Operator) {
-            iOperator = iOperator.id;
-        }
-
-        return this.ioperators[iOperator].preferences[key];
-    };
-
-    Wiring.prototype.setOperatorPrefValue = function setOperatorPrefValue(iOperator, key, value) {
-        var entry;
-
-        if (iOperator instanceof Wirecloud.Operator) {
-            iOperator = iOperator.id;
-        }
-
-        this.ioperators[iOperator].preferences[key] = value;
-    };
-
-    Wiring.prototype.registerOperatorPrefCallback = function registerOperatorPrefCallback(iOperator, callback) {
-        var entry;
-
-        if (iOperator instanceof Wirecloud.Operator) {
-            iOperator = iOperator.id;
-        }
-
-        this.ioperators[iOperator].prefCallback = callback;
-    };
-
     Wiring.prototype._notifyOperatorUninstall = function _notifyOperatorUninstall(operator) {
         var id, msg, affected = false;
 
