@@ -1,23 +1,21 @@
 /*
- *     Copyright (c) 2012-2013 CoNWeT Lab., Universidad Politécnica de Madrid
- *     Copyright (c) 2012-2013 Center for Open Middleware
+ *     DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER
  *
- *     This file is part of Wirecloud Platform.
+ *     Copyright (c) 2012-2013 Universidad Politécnica de Madrid
+ *     Copyright (c) 2012-2013 the Center for Open Middleware
  *
- *     Wirecloud Platform is free software: you can redistribute it and/or
- *     modify it under the terms of the GNU Affero General Public License as
- *     published by the Free Software Foundation, either version 3 of the
- *     License, or (at your option) any later version.
+ *     Licensed under the Apache License, Version 2.0 (the
+ *     "License"); you may not use this file except in compliance
+ *     with the License.  You may obtain a copy of the License at
  *
- *     Wirecloud is distributed in the hope that it will be useful, but WITHOUT
- *     ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- *     FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public
- *     License for more details.
- *
- *     You should have received a copy of the GNU Affero General Public License
- *     along with Wirecloud Platform.  If not, see
- *     <http://www.gnu.org/licenses/>.
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
+ *     Unless required by applicable law or agreed to in writing,
+ *     software distributed under the License is distributed on an
+ *     "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ *     KIND, either express or implied.  See the License for the
+ *     specific language governing permissions and limitations
+ *     under the License.
  */
 
 /*global Constants, EzWebExt, LayoutManagerFactory, opManager, StyledElements, Wirecloud, gettext, Draggable */
@@ -128,6 +126,14 @@ if (!Wirecloud.ui) {
 
     WiringEditor.prototype.view_name = 'wiring';
 
+    WiringEditor.prototype.buildStateData = function buildStateData() {
+        var data = EzWebExt.merge(HistoryManager.getCurrentState(), {
+            view: 'wiring'
+        });
+
+        return data;
+    };
+
     /*************************************************************************
      * Private methods
      *************************************************************************/
@@ -358,8 +364,8 @@ if (!Wirecloud.ui) {
             } else {
                 operator_instance = reallyInUseOperators[key];
             }
-            op_id = operator_instance.id;
-            if (this.nextOperatorId < op_id) {
+            op_id = parseInt(operator_instance.id, 10);
+            if (this.nextOperatorId <= op_id) {
                 this.nextOperatorId = op_id + 1;
             }
 
