@@ -1,23 +1,21 @@
 /*
- *     Copyright (c) 2012-2013 CoNWeT Lab., Universidad Politécnica de Madrid
- *     Copyright (c) 2012-2013 Center for Open Middleware
+ *     DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER
  *
- *     This file is part of Wirecloud Platform.
+ *     Copyright (c) 2012-2013 Universidad Politécnica de Madrid
+ *     Copyright (c) 2012-2013 the Center for Open Middleware
  *
- *     Wirecloud Platform is free software: you can redistribute it and/or
- *     modify it under the terms of the GNU Affero General Public License as
- *     published by the Free Software Foundation, either version 3 of the
- *     License, or (at your option) any later version.
+ *     Licensed under the Apache License, Version 2.0 (the
+ *     "License"); you may not use this file except in compliance
+ *     with the License.  You may obtain a copy of the License at
  *
- *     Wirecloud is distributed in the hope that it will be useful, but WITHOUT
- *     ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- *     FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public
- *     License for more details.
- *
- *     You should have received a copy of the GNU Affero General Public License
- *     along with Wirecloud Platform.  If not, see
- *     <http://www.gnu.org/licenses/>.
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
+ *     Unless required by applicable law or agreed to in writing,
+ *     software distributed under the License is distributed on an
+ *     "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ *     KIND, either express or implied.  See the License for the
+ *     specific language governing permissions and limitations
+ *     under the License.
  */
 
 /*global Draggable, gettext, interpolate, StyledElements, Wirecloud, EzWebExt, LayoutManagerFactory */
@@ -26,20 +24,34 @@
 
     "use strict";
 
+    /*************************************************************************
+     * Private functions
+     *************************************************************************/
+
+    var updateErrorInfo = function updateErrorInfo() {
+        var label, errorCount = this.entity.logManager.getErrorCount();
+        this.log_button.setDisabled(errorCount === 0);
+
+        label = ngettext("%(errorCount)s error", "%(errorCount)s errors", errorCount);
+        label = interpolate(label, {errorCount: errorCount}, true);
+        this.log_button.setTitle(label);
+    };
+
     /*************************************************************************
      * Constructor
      *************************************************************************/
     /**
      * GenericInterface Class
      */
-    var GenericInterface = function GenericInterface(extending, wiringEditor, title, manager, className, isGhost) {
+    var GenericInterface = function GenericInterface(extending, wiringEditor, entity, title, manager, className, isGhost) {
         if (extending === true) {
             return;
         }
-        var del_button, item, type, msg, ghostNotification;
+        var del_button, log_button, item, type, msg, ghostNotification;
 
         StyledElements.Container.call(this, {'class': className}, []);
 
+        Object.defineProperty(this, 'entity', {value: entity});
         this.editingPos = false;
         this.targetAnchorsByName = {};
         this.sourceAnchorsByName = {};
@@ -124,6 +136,24 @@
                 }
             }.bind(this));
 
+            // Log button
+            this.log_button = new StyledElements.StyledButton({
+                'plain': true,
+                'class': 'logbutton icon-warning-sign'
+            });
+            if (!isGhost) {
+                this.log_button.addEventListener("click",
+                    function () {
+                        var dialog = new Wirecloud.ui.LogWindowMenu(this.entity.logManager);
+                        dialog.show();
+                    }.bind(this));
+                updateErrorInfo.call(this);
+                this.entity.logManager.addEventListener('newentry', updateErrorInfo.bind(this));
+            } else {
+                this.log_button.disable();
+            }
+            this.log_button.insertInto(this.header);
+
             // special icon for minimized interface
             this.iconAux = document.createElement("div");
             this.iconAux.classList.add("specialIcon");
