@@ -33,7 +33,8 @@
         Object.defineProperty(this, 'meta', {value: operator_meta});
         Object.defineProperty(this, 'name', {value: operator_meta.name});
         Object.defineProperty(this, 'display_name', {value: operator_meta.display_name});
-        Object.defineProperty(this, 'id', {value: id});
+        Object.defineProperty(this, 'id', {value: "" + id});
+        Object.defineProperty(this, 'logManager', {value: new Wirecloud.wiring.OperatorLogManager(this)});
 
         this.loaded = false;
 
@@ -60,9 +61,14 @@
 
         for (key in this.meta.preferences) {
             if (!(key in preferences)) {
-                preferences[key] = this.meta.preferences[key].default_value;
+                preferences[key] = {
+                    'readonly': false,
+                    'hidden': false,
+                    'value': this.meta.preferences[key].default_value
+                };
             }
         }
+        Object.freeze(preferences);
         Object.defineProperty(this, 'preferences', {value: preferences});
 
         if (!wiringEditor) {
