@@ -1,26 +1,25 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2013 Universidad Politécnica de Madrid
+# Copyright (c) 2013 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
 # Wirecloud is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
+# it under the terms of the GNU Affero General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 
 # Wirecloud is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
 
 import json
 import os
-from tempfile import mkdtemp
 import shutil
 
 from django.core.urlresolvers import reverse
@@ -28,12 +27,8 @@ from django.test import Client
 
 from wirecloud.catalogue import utils as catalogue
 from wirecloud.catalogue.models import CatalogueResource
-import wirecloud.commons
-from wirecloud.commons.utils import downloader
-from wirecloud.commons.utils.testcases import LocalDownloader, WirecloudTestCase
-from wirecloud.commons.utils.wgt import WgtDeployer
+from wirecloud.commons.utils.testcases import WirecloudTestCase
 from wirecloud.platform.models import IWidget, Tab, VariableValue, Workspace, UserWorkspace
-from wirecloud.platform.widget import utils as showcase
 
 
 # Avoid nose to repeat these tests (they are run through wirecloud/platform/tests/__init__.py)
@@ -215,22 +210,10 @@ class ApplicationMashupAPI(WirecloudTestCase):
     fixtures = ('selenium_test_data', 'user_with_workspaces')
     tags = ('rest_api', 'fiware-ut-11')
 
-    @classmethod
-    def setUpClass(cls):
-        super(ApplicationMashupAPI, cls).setUpClass()
+    def setUp(self):
+        super(ApplicationMashupAPI, self).setUp()
 
-        cls.client = Client()
-        cls._original_download_function = staticmethod(downloader.download_http_content)
-        downloader.download_http_content = LocalDownloader({
-            'http': {
-                'localhost:8001': os.path.join(os.path.dirname(wirecloud.commons.__file__), 'test-data', 'src'),
-            },
-        })
-
-    @classmethod
-    def tearDownClass(cls):
-
-        downloader.download_http_content = cls._original_download_function
+        self.client = Client()
 
     def test_features(self):
 
@@ -441,7 +424,9 @@ class ApplicationMashupAPI(WirecloudTestCase):
         self.assertTrue('description' in response_data)
         self.assertTrue('details' in response_data)
         self.assertTrue('missingDependencies' in response_data['details'])
-        self.assertEqual(set(response_data['details']['missingDependencies']), set((
+        missingDependencies = set(response_data['details']['missingDependencies'])
+        self.assertEqual(len(response_data['details']['missingDependencies']), len(missingDependencies))
+        self.assertEqual(missingDependencies, set((
             'Wirecloud/nonavailable-operator/1.0',
             'Wirecloud/nonavailable-widget/1.0',
             'Wirecloud/TestOperator/1.0',
@@ -610,7 +595,7 @@ class ApplicationMashupAPI(WirecloudTestCase):
 
         url = reverse('wirecloud.workspace_wiring', kwargs={'workspace_id': 1})
         data = {
-            'operators': [{'name': 'Operator1'}],
+            'operators': {'0': {'name': 'Operator1'}},
             'connections': [],
         }
         check_put_requires_permission(self, url, json.dumps(data))
@@ -619,7 +604,7 @@ class ApplicationMashupAPI(WirecloudTestCase):
 
         url = reverse('wirecloud.workspace_wiring', kwargs={'workspace_id': 1})
         new_wiring_status = {
-            'operators': [{'name': 'Operator1'}],
+            'operators': {'0': {'name': 'Operator1'}},
             'connections': [],
         }
 
@@ -802,6 +787,22 @@ class ApplicationMashupAPI(WirecloudTestCase):
         # Tab should be removed
         self.assertFalse(Tab.objects.filter(name='ExistingTab').exists())
 
+    def test_tab_entry_delete_read_only_widgets(self):
+
+        url = reverse('wirecloud.tab_entry', kwargs={'workspace_id': 3, 'tab_id': 103})
+
+        # Authenticate
+        self.client.login(username='user_with_workspaces', password='admin')
+
+        # Make the request
+        response = self.client.delete(url, HTTP_ACCEPT='application/json')
+        self.assertEqual(response.status_code, 403)
+        response_data = json.loads(response.content)
+        self.assertTrue(isinstance(response_data, dict))
+
+        # Tab should not be removed
+        self.assertTrue(Tab.objects.filter(pk=103).exists())
+
     def test_iwidget_collection_post_requires_authentication(self):
 
         url = reverse('wirecloud.iwidget_collection', kwargs={'workspace_id': 1, 'tab_id': 1})
@@ -836,6 +837,44 @@ class ApplicationMashupAPI(WirecloudTestCase):
         response_data = json.loads(response.content)
         self.assertTrue(isinstance(response_data, dict))
 
+    def test_iwidget_collection_post_creation_from_nonexistent_widget(self):
+
+        url = reverse('wirecloud.iwidget_collection', kwargs={'workspace_id': 1, 'tab_id': 1})
+
+        # Authenticate
+        self.client.login(username='user_with_workspaces', password='admin')
+
+        # Make the request
+        data = {
+            'widget': 'Wirecloud/nonexistent-widget/1.0',
+        }
+        response = self.client.post(url, json.dumps(data), content_type='application/json', HTTP_ACCEPT='application/json')
+        self.assertEqual(response.status_code, 422)
+        response_data = json.loads(response.content)
+        self.assertTrue(isinstance(response_data, dict))
+
+    def test_iwidget_collection_post_creation_from_nonavailable_widget(self):
+
+        url = reverse('wirecloud.iwidget_collection', kwargs={'workspace_id': 1, 'tab_id': 1})
+
+        # Make Wirecloud/Test/1.0 not available to user_with_workspaces
+        test_widget = CatalogueResource.objects.get(vendor='Wirecloud', short_name='Test', version='1.0')
+        test_widget.public = False
+        test_widget.users.clear()
+        test_widget.save()
+
+        # Authenticate
+        self.client.login(username='user_with_workspaces', password='admin')
+
+        # Make the request
+        data = {
+            'widget': 'Wirecloud/Test/1.0',
+        }
+        response = self.client.post(url, json.dumps(data), content_type='application/json', HTTP_ACCEPT='application/json')
+        self.assertEqual(response.status_code, 422)
+        response_data = json.loads(response.content)
+        self.assertTrue(isinstance(response_data, dict))
+
     def test_iwidget_collection_post_bad_request_syntax(self):
 
         url = reverse('wirecloud.iwidget_collection', kwargs={'workspace_id': 1, 'tab_id': 1})
@@ -975,47 +1014,27 @@ class ApplicationMashupAPI(WirecloudTestCase):
         # IWidget should be deleted
         self.assertRaises(IWidget.DoesNotExist, IWidget.objects.get, pk=2)
 
+    def test_iwidget_entry_delete_read_only(self):
+
+        url = reverse('wirecloud.iwidget_entry', kwargs={'workspace_id': 3, 'tab_id': 103, 'iwidget_id': 4})
+
+        # Authenticate
+        self.client.login(username='user_with_workspaces', password='admin')
+
+        # Make the request
+        response = self.client.delete(url, HTTP_ACCEPT='application/json')
+        self.assertEqual(response.status_code, 403)
+        response_data = json.loads(response.content)
+        self.assertTrue(isinstance(response_data, dict))
+
+        # IWidget should not be deleted
+        IWidget.objects.get(pk=4)
 
 class ResourceManagementAPI(WirecloudTestCase):
 
     fixtures = ('selenium_test_data',)
     tags = ('rest_api', 'fiware-ut-11')
 
-    @classmethod
-    def setUpClass(cls):
-        super(ResourceManagementAPI, cls).setUpClass()
-
-        cls.client = Client()
-        cls._original_download_function = staticmethod(downloader.download_http_content)
-        downloader.download_http_content = LocalDownloader({
-            'http': {
-                'localhost:8001': os.path.join(os.path.dirname(wirecloud.commons.__file__), 'test-data', 'src'),
-            },
-        })
-
-        # catalogue deployer
-        cls.old_catalogue_deployer = catalogue.wgt_deployer
-        cls.catalogue_tmp_dir = mkdtemp()
-        catalogue.wgt_deployer = WgtDeployer(cls.catalogue_tmp_dir)
-
-        # showcase deployer
-        cls.old_deployer = showcase.wgt_deployer
-        cls.showcase_tmp_dir = mkdtemp()
-        showcase.wgt_deployer = WgtDeployer(cls.showcase_tmp_dir)
-
-    @classmethod
-    def tearDownClass(cls):
-
-        downloader.download_http_content = cls._original_download_function
-
-        # deployers
-        catalogue.wgt_deployer = cls.old_catalogue_deployer
-        shutil.rmtree(cls.catalogue_tmp_dir, ignore_errors=True)
-        showcase.wgt_deployer = cls.old_deployer
-        shutil.rmtree(cls.showcase_tmp_dir, ignore_errors=True)
-
-        super(ResourceManagementAPI, cls).tearDownClass()
-
     def test_resource_collection_get_requires_authentication(self):
 
         url = reverse('wirecloud_showcase.resource_collection')
@@ -1069,6 +1088,30 @@ class ResourceManagementAPI(WirecloudTestCase):
         self.assertIn('version', response_data)
         self.assertEqual(response_data['version'], '1.0')
 
+    def test_resource_collection_post_widget_without_enough_filesystem_permissions(self):
+
+        url = reverse('wirecloud_showcase.resource_collection')
+
+        resource_id = [
+            'Wirecloud',
+            'Test_Selenium',
+            '1.0'
+        ]
+        local_dir = catalogue.wgt_deployer.get_base_dir(*resource_id)
+        os.makedirs(local_dir)
+        os.chmod(local_dir, 0)
+
+        # Authenticate
+        self.client.login(username='admin', password='admin')
+
+        # Make the request
+        with open(os.path.join(self.shared_test_data_dir, 'Wirecloud_Test_Selenium_1.0.wgt'), 'rb') as f:
+            response = self.client.post(url, data={'file': f}, HTTP_ACCEPT='application/json')
+        self.assertEqual(response.status_code, 500)
+        self.assertEqual(response['Content-Type'].split(';', 1)[0], 'application/json')
+        response_data = json.loads(response.content)
+        self.assertTrue(isinstance(response_data, dict))
+
     def test_resource_collection_post_widget_invalid_html_encoding(self):
 
         url = reverse('wirecloud_showcase.resource_collection')
@@ -1257,41 +1300,6 @@ class ExtraApplicationMashupAPI(WirecloudTestCase):
     fixtures = ('initial_data', 'selenium_test_data', 'user_with_workspaces')
     tags = ('extra_rest_api',)
 
-    @classmethod
-    def setUpClass(cls):
-        super(ExtraApplicationMashupAPI, cls).setUpClass()
-
-        cls.client = Client()
-        cls._original_download_function = staticmethod(downloader.download_http_content)
-        downloader.download_http_content = LocalDownloader({
-            'http': {
-                'localhost:8001': os.path.join(os.path.dirname(wirecloud.commons.__file__), 'test-data', 'src'),
-            },
-        })
-
-        # catalogue deployer
-        cls.old_catalogue_deployer = catalogue.wgt_deployer
-        cls.catalogue_tmp_dir = mkdtemp()
-        catalogue.wgt_deployer = WgtDeployer(cls.catalogue_tmp_dir)
-
-        # showcase deployer
-        cls.old_deployer = showcase.wgt_deployer
-        cls.showcase_tmp_dir = mkdtemp()
-        showcase.wgt_deployer = WgtDeployer(cls.showcase_tmp_dir)
-
-    @classmethod
-    def tearDownClass(cls):
-
-        downloader.download_http_content = cls._original_download_function
-
-        # deployers
-        catalogue.wgt_deployer = cls.old_catalogue_deployer
-        shutil.rmtree(cls.catalogue_tmp_dir, ignore_errors=True)
-        showcase.wgt_deployer = cls.old_deployer
-        shutil.rmtree(cls.showcase_tmp_dir, ignore_errors=True)
-
-        super(ExtraApplicationMashupAPI, cls).tearDownClass()
-
     def test_iwidget_collection_get_requires_authentication(self):
 
         url = reverse('wirecloud.iwidget_collection', kwargs={'workspace_id': 2, 'tab_id': 101})
@@ -1775,6 +1783,11 @@ class ExtraApplicationMashupAPI(WirecloudTestCase):
         self.assertEqual(response.status_code, 204)
         self.assertEqual(response.content, '')
 
+    def test_tab_preference_collection_post_bad_request_syntax(self):
+
+        url = reverse('wirecloud.tab_preferences', kwargs={'workspace_id': 2, 'tab_id': 101})
+        check_post_bad_request_syntax(self, url)
+
     def test_workspace_publish_requires_authentication(self):
 
         url = reverse('wirecloud.workspace_publish', kwargs={'workspace_id': 2})
