@@ -1,20 +1,20 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012-2013 Universidad Politécnica de Madrid
+# Copyright (c) 2012-2013 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
 # Wirecloud is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
+# it under the terms of the GNU Affero General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 
 # Wirecloud is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
 
@@ -50,19 +50,19 @@ class BasicSeleniumTests(WirecloudSeleniumTestCase):
         # Only one tab => we cannot remove it
         tab_menu_button = tab.find_element_by_css_selector('.icon-tab-menu')
         tab_menu_button.click()
-        self.check_popup_menu(('Rename',), ('Remove',))
+        self.check_popup_menu(('Rename',), must_be_disabled=('Remove',))
 
         new_tab = self.add_tab()
 
         # Now we have two tabs so we can remove any of them
         tab_menu_button = tab.find_element_by_css_selector('.icon-tab-menu')
         tab_menu_button.click()
-        self.check_popup_menu(('Rename', 'Remove'), ())
+        self.check_popup_menu(must_be=('Rename', 'Remove'))
 
         new_tab.click()
         tab_menu_button = new_tab.find_element_by_css_selector('.icon-tab-menu')
         tab_menu_button.click()
-        self.check_popup_menu(('Rename', 'Remove'), ())
+        self.check_popup_menu(must_be=('Rename', 'Remove'))
 
         # Remove the recently created one
         self.popup_menu_click('Remove')
@@ -90,6 +90,32 @@ class BasicSeleniumTests(WirecloudSeleniumTestCase):
         iwidget.remove()
     test_remove_widget_from_workspace.tags = ('fiware-ut-5',)
 
+    def test_read_only_widgets_cannot_be_removed(self):
+
+        self.login(username='user_with_workspaces')
+
+        self.change_current_workspace('Pending Events')
+
+        tab = self.get_workspace_tab_by_name('Tab 2')
+        tab.click()
+
+        iwidget = self.get_current_iwidgets()[1]
+        iwidget.wait_loaded()
+        close_button = iwidget.element.find_element_by_css_selector('.icon-remove')
+        self.assertTrue('disabled' in close_button.get_attribute('class'))
+
+    def test_tabs_with_read_only_widgets_cannot_be_removed(self):
+
+        self.login(username='user_with_workspaces')
+
+        self.change_current_workspace('Pending Events')
+
+        tab = self.get_workspace_tab_by_name('Tab 2')
+        tab.click()
+        tab_menu_button = self.wait_element_visible_by_css_selector('.icon-tab-menu', element=tab)
+        tab_menu_button.click()
+        self.check_popup_menu(must_be_disabled=('Remove',))
+
     def test_widget_reload(self):
 
         self.login(username='user_with_workspaces')
@@ -120,9 +146,16 @@ class BasicSeleniumTests(WirecloudSeleniumTestCase):
             self.assertEqual(self.driver.find_element_by_id('booleanPref').text, 'false')
             self.assertEqual(self.driver.find_element_by_id('passwordPref').text, 'default')
 
-        # Change widget settings
+        # Open widget settings
         iwidget.perform_action('Settings')
 
+        # Check dialog shows correct values
+        self.assertEqual(self.driver.find_element_by_css_selector('.window_menu [name="list"]').get_attribute('value'), 'default')
+        self.assertEqual(self.driver.find_element_by_css_selector('.window_menu [name="text"]').get_attribute('value'), 'initial text')
+        self.assertFalse(self.driver.find_element_by_css_selector('.window_menu [name="boolean"]').is_selected())
+        self.assertEqual(self.driver.find_element_by_css_selector('.window_menu [name="password"]').get_attribute('value'), 'default')
+
+        # Change widget settings
         list_input = self.driver.find_element_by_css_selector('.window_menu [name="list"]')
         self.fill_form_input(list_input, '1')  # value1
         text_input = self.driver.find_element_by_css_selector('.window_menu [name="text"]')
@@ -140,9 +173,16 @@ class BasicSeleniumTests(WirecloudSeleniumTestCase):
             self.assertEqual(self.driver.find_element_by_id('booleanPref').text, 'true')
             self.assertEqual(self.driver.find_element_by_id('passwordPref').text, 'password')
 
-        # Change widget settings again
+        # Open widget settings again
         iwidget.perform_action('Settings')
 
+        # Check dialog shows correct values
+        self.assertEqual(self.driver.find_element_by_css_selector('.window_menu [name="list"]').get_attribute('value'), '1')
+        self.assertEqual(self.driver.find_element_by_css_selector('.window_menu [name="text"]').get_attribute('value'), 'test')
+        self.assertTrue(self.driver.find_element_by_css_selector('.window_menu [name="boolean"]').is_selected())
+        self.assertEqual(self.driver.find_element_by_css_selector('.window_menu [name="password"]').get_attribute('value'), 'password')
+
+        # Change widget settings
         text_input = self.driver.find_element_by_css_selector('.window_menu [name="text"]')
         self.fill_form_input(text_input, '')
         password_input = self.driver.find_element_by_css_selector('.window_menu [name="password"]')
@@ -157,7 +197,17 @@ class BasicSeleniumTests(WirecloudSeleniumTestCase):
             self.assertEqual(self.driver.find_element_by_id('passwordPref').text, '')
 
         # Use api test widget to test other API features
+
+        # Open widget settings again
+        api_test_iwidget.perform_action('Settings')
+
+        text_input = self.driver.find_element_by_css_selector('.window_menu [name="text"]')
+        self.fill_form_input(text_input, 'Success!!')
+
+        self.driver.find_element_by_xpath("//*[contains(@class, 'window_menu')]//*[text()='Accept']").click()
+
         with api_test_iwidget:
+            self.assertEqual(self.driver.find_element_by_id('pref_registercallback_test').text, 'Success!!')
             self.assertEqual(self.driver.find_element_by_id('makerequest_test').text, 'Success!!')
             prop_input = self.driver.find_element_by_css_selector('#update_prop_input')
             self.fill_form_input(prop_input, 'new value')
@@ -216,7 +266,7 @@ class BasicSeleniumTests(WirecloudSeleniumTestCase):
         self.assertIsNotNone(target_iwidget.element)
 
         tab = self.get_workspace_tab_by_name('Tab 2')
-        tab.click();
+        tab.click()
 
         with target_iwidget:
             try:
@@ -359,6 +409,49 @@ class BasicSeleniumTests(WirecloudSeleniumTestCase):
             self.assertEqual(text_div.text, 'hello world!!')
     test_create_workspace_from_catalogue.tags = ('fiware-ut-5',)
 
+    @uses_extra_resources(('Wirecloud_ParameterizedMashup_1.0.zip',), shared=True)
+    def test_create_workspace_from_catalogue_using_parameters(self):
+
+        self.login()
+        self.create_workspace_from_catalogue('ParameterizedMashup', parameters={
+            'text_param': 'parameterized value',
+            'password_param': 'parameterized password',
+        })
+
+        iwidget = self.get_current_iwidgets()[0]
+
+        iwidget.perform_action('Settings')
+
+        self.assertEqual(self.driver.find_element_by_css_selector('.window_menu [name="list"]').get_attribute('value'), 'default')
+        text_pref = self.driver.find_element_by_css_selector('.window_menu [name="text"]')
+        self.assertEqual(text_pref.get_attribute('disabled'), 'true')
+        self.assertEqual(text_pref.get_attribute('value'), 'parameterized value')
+
+        self.assertFalse(self.driver.find_element_by_css_selector('.window_menu [name="boolean"]').is_selected())
+        password_prefs = self.driver.find_elements_by_css_selector('.window_menu [name="password"]')
+        self.assertEqual(len(password_prefs), 0)
+
+        self.driver.find_element_by_xpath("//*[contains(@class, 'window_menu')]//*[text()='Cancel']").click()
+
+        with iwidget:
+            self.assertEqual(self.driver.find_element_by_id('listPref').text, 'default')
+            self.assertEqual(self.driver.find_element_by_id('textPref').text, 'parameterized value')
+            self.assertEqual(self.driver.find_element_by_id('booleanPref').text, 'false')
+            self.assertEqual(self.driver.find_element_by_id('passwordPref').text, 'parameterized password')
+
+        self.change_main_view('wiring')
+
+        ioperator = self.get_current_wiring_editor_ioperators()[0]
+        ioperator.element.find_element_by_css_selector('.specialIcon').click()
+        self.wait_element_visible_by_css_selector('.editPos_button', element=ioperator.element).click()
+        self.popup_menu_click('Settings')
+
+        prefix_pref = self.driver.find_element_by_css_selector('.window_menu [name="prefix"]')
+        self.assertEqual(prefix_pref.get_attribute('disabled'), 'true')
+        self.assertEqual(prefix_pref.get_attribute('value'), 'parameterized value: ')
+
+        self.driver.find_element_by_xpath("//*[contains(@class, 'window_menu')]//*[text()='Cancel']").click()
+
     def test_create_workspace_from_catalogue_duplicated_workspaces(self):
 
         self.login()
@@ -421,3 +514,57 @@ class BasicSeleniumTests(WirecloudSeleniumTestCase):
         self.search_resource('Published Workspace')
         mashup = self.search_in_catalogue_results('Published Workspace')
         self.assertIsNotNone(mashup, 'The published workspace is not available on the local catalogue')
+
+    def test_workspace_publish_readonly_widgets_and_connections(self):
+
+        self.login(username='user_with_workspaces')
+
+        self.publish_workspace({
+            'vendor': 'Wirecloud',
+            'name': 'Published Workspace',
+            'version': '1.0',
+            'email': 'a@b.com',
+            'readOnlyWidgets': True,
+            'readOnlyConnectables': True,
+        })
+        self.create_workspace_from_catalogue('Published Workspace')
+        iwidget = self.get_current_iwidgets()[0]
+        close_button = iwidget.element.find_element_by_css_selector('.icon-remove')
+        self.assertTrue('disabled' in close_button.get_attribute('class'))
+        close_button.click()
+
+        self.change_main_view('wiring')
+
+        wiring_canvas = self.driver.find_element_by_css_selector('.grid .canvas')
+        arrows = wiring_canvas.find_elements_by_css_selector('.arrow')
+        self.assertEqual(len(arrows), 3)
+        for arrow in arrows:
+            try:
+                # The find_element_by_css_selector is needed to work around a bug in the firefox driver
+                arrow.find_element_by_css_selector('g').click()
+                self.wait_element_visible_by_css_selector('.closer', element=arrow).click()
+            except:
+                pass
+        arrows = wiring_canvas.find_elements_by_css_selector('.arrow')
+        self.assertEqual(len(arrows), 3)
+
+        self.change_main_view('workspace')
+
+        self.assertEqual(len(self.get_current_iwidgets()), 2)
+
+    def test_browser_navigation_history_management(self):
+
+        self.login(username='user_with_workspaces')
+
+        self.change_main_view('wiring')
+        self.change_main_view('marketplace')
+        self.change_main_view('wiring')
+
+        self.driver.back()
+        WebDriverWait(self.driver, timeout=10).until(lambda driver: self.get_current_view() == 'marketplace')
+        self.driver.back()
+        WebDriverWait(self.driver, timeout=10).until(lambda driver: self.get_current_view() == 'wiring')
+        self.driver.back()
+        WebDriverWait(self.driver, timeout=10).until(lambda driver: self.get_current_view() == 'workspace')
+        self.driver.back()
+        self.assertEqual(self.driver.current_url, self.live_server_url + '/login')
