@@ -1,34 +1,22 @@
 # -*- coding: utf-8 -*-
 
-#...............................licence...........................................
-#
-#     (C) Copyright 2008 Telefonica Investigacion y Desarrollo
-#     S.A.Unipersonal (Telefonica I+D)
-#
-#     This file is part of Morfeo EzWeb Platform.
-#
-#     Morfeo EzWeb Platform is free software: you can redistribute it and/or modify
-#     it under the terms of the GNU Affero General Public License as published by
-#     the Free Software Foundation, either version 3 of the License, or
-#     (at your option) any later version.
-#
-#     Morfeo EzWeb Platform is distributed in the hope that it will be useful,
-#     but WITHOUT ANY WARRANTY; without even the implied warranty of
-#     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#     GNU Affero General Public License for more details.
-#
-#     You should have received a copy of the GNU Affero General Public License
-#     along with Morfeo EzWeb Platform.  If not, see <http://www.gnu.org/licenses/>.
-#
-#     Info about members and contributors of the MORFEO project
-#     is available at
-#
-#     http://morfeo-project.org
-#
-#...............................licence...........................................#
+# Copyright (c) 2011-2013 CoNWeT Lab., Universidad Politécnica de Madrid
 
+# This file is part of Wirecloud.
+
+# Wirecloud is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Affero General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+
+# Wirecloud is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Affero General Public License for more details.
+
+# You should have received a copy of the GNU Affero General Public License
+# along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
-#
 from lxml import etree
 from cStringIO import StringIO
 
@@ -226,21 +214,13 @@ def create_widget_from_wgt(wgt, user, deploy_only=False):
 
 
 def get_or_add_widget_from_catalogue(vendor, name, version, user, request=None, assign_to_users=None):
-    resource_exists = CatalogueResource.objects.filter(vendor=vendor, short_name=name, version=version).filter(Q(public=True) | Q(users=user)).exists()
-    widget_exists = resource_exists and Widget.objects.filter(resource__vendor=vendor, resource__short_name=name, resource__version=version).exists()
-    if resource_exists and widget_exists:
-        resource = CatalogueResource.objects.get(vendor=vendor, short_name=name, version=version)
-    else:
-        from wirecloud.platform.localcatalogue.utils import install_resource_from_available_marketplaces
-        resource = install_resource_from_available_marketplaces(vendor, name, version, user)
+    resource_list = CatalogueResource.objects.filter(Q(vendor=vendor, version=version) & (Q(short_name=name) | Q(short_name__startswith=(name + '@'))))
 
-    if assign_to_users is None:
-        assign_to_users = (user,)
+    for resource in resource_list:
+        if resource.is_available_for(user):
+            return resource.widget
 
-    for user in assign_to_users:
-        resource.users.add(user)
-
-    return resource.widget
+    return None
 
 
 def xpath(tree, query, xmlns):
