@@ -29,6 +29,7 @@ from django.contrib.auth.models import User
 from django.db import transaction
 from django.test import TransactionTestCase, Client
 from django.utils import unittest
+import selenium
 from selenium.common.exceptions import NoSuchElementException
 from selenium.webdriver.common.action_chains import ActionChains
 from selenium.webdriver.support.ui import WebDriverWait
@@ -41,10 +42,17 @@ from wirecloud.platform.workspace.models import Workspace
 # Avoid nose to repeat these tests (they are run through wirecloud/tests.py)
 __test__ = False
 
+SELENIUM_VERSION = tuple(selenium.__version__.split('.'))
+
+
+def selenium_supports_draganddrop(driver):
+    return driver.capabilities['browserName'] != 'firefox' or SELENIUM_VERSION >= (2, 37, 2) or driver.profile.native_events_enabled
+
 
 class WiringTestCase(TransactionTestCase):
 
     fixtures = ('test_data',)
+    tags = ('wiring',)
 
     def setUp(self):
 
@@ -88,7 +96,7 @@ class WiringTestCase(TransactionTestCase):
         response = client.put(self.wiring_url, data, content_type='application/json')
 
         self.assertEqual(response.status_code, 204)
-    test_save_basic_wiring_connection.tags = ('fiware-ut-6',)
+    test_save_basic_wiring_connection.tags = ('wiring', 'fiware-ut-6')
 
     def test_wiring_modification_fails_with_incorrect_user(self):
         client = Client()
@@ -100,7 +108,7 @@ class WiringTestCase(TransactionTestCase):
         })
         response = client.put(self.wiring_url, data, content_type='application/json')
         self.assertEqual(response.status_code, 403)
-    test_wiring_modification_fails_with_incorrect_user.tags = ('fiware-ut-6',)
+    test_wiring_modification_fails_with_incorrect_user.tags = ('wiring', 'fiware-ut-6')
 
     def test_basic_wiring_operations_with_read_only_connections(self):
         workspace = Workspace.objects.get(id=1)
@@ -313,6 +321,9 @@ class OperatorCodeEntryTestCase(WirecloudTestCase):
 
 class WiringSeleniumTestCase(WirecloudSeleniumTestCase):
 
+    fixtures = ('initial_data', 'selenium_test_data', 'user_with_workspaces')
+    tags = ('wiring', 'wiring_editor')
+
     def test_operators_are_usable_after_installing(self):
 
         self.login()
@@ -320,14 +331,13 @@ class WiringSeleniumTestCase(WirecloudSeleniumTestCase):
         self.add_packaged_resource_to_catalogue('Wirecloud_TestOperatorSelenium_1.0.zip', 'TestOperatorSelenium', shared=True)
 
         self.change_main_view('wiring')
-        time.sleep(2)
 
         wiring_base_element = self.driver.find_element_by_css_selector('.wiring_editor')
         menubar = wiring_base_element.find_element_by_css_selector('.menubar')
 
         menubar.find_element_by_xpath("//*[contains(@class, 'styled_expander')]//*[contains(@class, 'title') and text()='Operators']").click()
         menubar.find_element_by_xpath("//*[contains(@class, 'container ioperator')]//*[text()='TestOperatorSelenium']")
-    test_operators_are_usable_after_installing.tags = ('fiware-ut-6',)
+    test_operators_are_usable_after_installing.tags = ('wiring', 'wiring_editor', 'fiware-ut-6')
 
     def test_operators_are_not_usable_after_being_uninstalled(self):
 
@@ -336,14 +346,13 @@ class WiringSeleniumTestCase(WirecloudSeleniumTestCase):
         self.uninstall_resource('TestOperator')
 
         self.change_main_view('wiring')
-        time.sleep(2)
 
         wiring_base_element = self.driver.find_element_by_css_selector('.wiring_editor')
         menubar = wiring_base_element.find_element_by_css_selector('.menubar')
 
         menubar.find_element_by_xpath("//*[contains(@class, 'styled_expander')]//*[contains(@class, 'title') and text()='Operators']").click()
         self.assertRaises(NoSuchElementException, menubar.find_element_by_xpath, "//*[contains(@class, 'container ioperator')]//*[text()='TestOperator']")
-    test_operators_are_not_usable_after_being_uninstalled.tags = ('fiware-ut-6',)
+    test_operators_are_not_usable_after_being_uninstalled.tags = ('wiring', 'wiring_editor', 'fiware-ut-6')
 
     def test_operators_are_not_usable_after_being_deleted(self):
 
@@ -352,7 +361,6 @@ class WiringSeleniumTestCase(WirecloudSeleniumTestCase):
         self.delete_resource('TestOperator')
 
         self.change_main_view('wiring')
-        time.sleep(2)
 
         wiring_base_element = self.driver.find_element_by_css_selector('.wiring_editor')
         menubar = wiring_base_element.find_element_by_css_selector('.menubar')
@@ -362,8 +370,8 @@ class WiringSeleniumTestCase(WirecloudSeleniumTestCase):
 
     def test_basic_wiring_editor_operations(self):
 
-        if self.driver.capabilities['browserName'] == 'firefox' and not self.driver.profile.native_events_enabled:
-            raise unittest.SkipTest('This test need make use of the native events support when using FirefoxDriver (not available on Mac OS)')
+        if not selenium_supports_draganddrop(self.driver):
+            raise unittest.SkipTest('This test need make use of the native events support on selenium <= 2.37.2 when using FirefoxDriver (not available on Mac OS)')
 
         self.login()
 
@@ -373,7 +381,6 @@ class WiringSeleniumTestCase(WirecloudSeleniumTestCase):
         iwidgets = self.get_current_iwidgets()
 
         self.change_main_view('wiring')
-        time.sleep(2)
         grid = self.driver.find_element_by_xpath("//*[contains(@class, 'container center_container grid')]")
 
         source = self.driver.find_element_by_xpath("//*[contains(@class, 'container iwidget')]//*[text()='Test (1)']")
@@ -387,7 +394,6 @@ class WiringSeleniumTestCase(WirecloudSeleniumTestCase):
         ActionChains(self.driver).drag_and_drop(source.element, target.element).perform()
 
         self.change_main_view('workspace')
-        time.sleep(0.2)
 
         with iwidgets[0]:
             text_input = self.driver.find_element_by_tag_name('input')
@@ -414,12 +420,97 @@ class WiringSeleniumTestCase(WirecloudSeleniumTestCase):
         with iwidgets[0]:
             text_div = self.driver.find_element_by_id('wiringOut')
             self.assertEqual(text_div.text, '')
-    test_basic_wiring_editor_operations.tags = ('fiware-ut-6',)
+    test_basic_wiring_editor_operations.tags = ('wiring', 'fiware-ut-6')
+
+    def test_widget_preferences_in_wiring_editor(self):
+
+        self.login(username='user_with_workspaces')
+        iwidget = self.get_current_iwidgets()[0]
+
+        with iwidget:
+            self.assertEqual(self.driver.find_element_by_id('listPref').text, 'default')
+            self.assertEqual(self.driver.find_element_by_id('textPref').text, 'initial text')
+            self.assertEqual(self.driver.find_element_by_id('booleanPref').text, 'false')
+            self.assertEqual(self.driver.find_element_by_id('passwordPref').text, 'default')
+
+        self.change_main_view('wiring')
+
+        # Change widget settings
+        widget = self.wait_element_visible_by_css_selector('.grid > .iwidget')
+        widget.find_element_by_css_selector('.editPos_button').click()
+        self.popup_menu_click('Settings')
+
+        list_input = self.driver.find_element_by_css_selector('.window_menu [name="list"]')
+        self.fill_form_input(list_input, '1')  # value1
+        text_input = self.driver.find_element_by_css_selector('.window_menu [name="text"]')
+        self.fill_form_input(text_input, 'test')
+        boolean_input = self.driver.find_element_by_css_selector('.window_menu [name="boolean"]')
+        boolean_input.click()
+        password_input = self.driver.find_element_by_css_selector('.window_menu [name="password"]')
+        self.fill_form_input(password_input, 'password')
+
+        self.driver.find_element_by_xpath("//*[contains(@class, 'window_menu')]//*[text()='Accept']").click()
+
+        self.change_main_view('workspace')
+
+        with iwidget:
+            self.assertEqual(self.driver.find_element_by_id('listPref').text, '1')
+            self.assertEqual(self.driver.find_element_by_id('textPref').text, 'test')
+            self.assertEqual(self.driver.find_element_by_id('booleanPref').text, 'true')
+            self.assertEqual(self.driver.find_element_by_id('passwordPref').text, 'password')
+
+    def test_operator_preferences_in_wiring_editor(self):
+
+        self.login(username='user_with_workspaces')
+        iwidgets = self.get_current_iwidgets()
+
+        self.change_main_view('wiring')
+
+        # Change widget settings
+        ioperator = self.get_current_wiring_editor_ioperators()[0]
+        ioperator.element.find_element_by_css_selector('.specialIcon').click()
+        self.wait_element_visible_by_css_selector('.editPos_button', element=ioperator.element).click()
+        self.popup_menu_click('Settings')
+
+        prefix_input = self.driver.find_element_by_css_selector('.window_menu [name="prefix"]')
+        self.fill_form_input(prefix_input, 'prefix: ')
+
+        self.driver.find_element_by_xpath("//*[contains(@class, 'window_menu')]//*[text()='Accept']").click()
+
+        self.change_main_view('workspace')
+
+        with iwidgets[0]:
+            try:
+                WebDriverWait(self.driver, timeout=10).until(lambda driver: driver.find_element_by_id('wiringOut').text != '')
+            except:
+                pass
+
+            text_div = self.driver.find_element_by_id('wiringOut')
+            self.assertEqual(text_div.text, 'preferences changed: prefix')
+
+        with iwidgets[1]:
+            text_input = self.driver.find_element_by_tag_name('input')
+            self.fill_form_input(text_input, 'hello world!!')
+            # Work around hang when using Firefox Driver
+            self.driver.execute_script('sendEvent();')
+            #self.driver.find_element_by_id('b1').click()
+
+        time.sleep(0.2)
+
+        with iwidgets[0]:
+            try:
+                WebDriverWait(self.driver, timeout=10).until(lambda driver: driver.find_element_by_id('wiringOut').text != 'preferences changed: prefix')
+            except:
+                pass
+
+            text_div = self.driver.find_element_by_id('wiringOut')
+            self.assertEqual(text_div.text, 'prefix: hello world!!')
 
 
 class WiringRecoveringTestCase(WirecloudSeleniumTestCase):
 
     fixtures = ('initial_data', 'selenium_test_data', 'user_with_workspaces')
+    tags = ('wiring', 'wiring_editor')
 
     @uses_extra_resources(('Wirecloud_api-test_0.9.wgt',), shared=True)
     def test_wiring_recovers_from_invalid_views_data(self):
@@ -561,6 +652,7 @@ class WiringRecoveringTestCase(WirecloudSeleniumTestCase):
 class WiringGhostTestCase(WirecloudSeleniumTestCase):
 
     fixtures = ('initial_data', 'selenium_test_data', 'user_with_workspaces')
+    tags = ('wiring', 'wiring_editor')
 
     @uses_extra_resources(('Wirecloud_api-test_0.9.wgt',), shared=True)
     def test_wiring_show_invisible_widget(self):
@@ -630,21 +722,23 @@ class WiringGhostTestCase(WirecloudSeleniumTestCase):
 
         iwidgets = self.get_current_iwidgets()
         self.assertEqual(len(iwidgets), 2)
+
         self.change_main_view('wiring')
-        time.sleep(2)
+
+        # Check ghost widget
         ghostWidget = self.driver.find_elements_by_css_selector('.grid > .iwidget.ghost')
         ghostEndpointsLabelsFirst1 = self.driver.find_elements_by_css_selector('.grid > .iwidget.ghost .labelDiv')[0].text
         ghostEndpointsLabelsFirst2 = self.driver.find_elements_by_css_selector('.grid > .iwidget.ghost .labelDiv')[1].text
-        # Ghost
         self.assertEqual(len(ghostWidget), 1, "The ghost Widget has not been painted in the first access to Wiring Editor")
+
+        # Reload wiring Editor
         self.change_main_view('workspace')
-        time.sleep(2)
         self.change_main_view('wiring')
-        time.sleep(2)
+
+        # Check ghost widget
         ghostWidget = self.driver.find_elements_by_css_selector('.grid > .iwidget.ghost')
         self.assertEqual(len(ghostWidget), 1, "The ghost Widget has not been painted in the second access to Wiring Editor")
         ghostEndpointsLabelsSecond = self.driver.find_elements_by_css_selector('.grid > .iwidget.ghost .labelDiv')
-        # compare labels
         self.assertEqual(ghostEndpointsLabelsFirst1, ghostEndpointsLabelsSecond[0].text, "The ghost Widget has change the endpoints label in the second access to Wiring Editor")
         self.assertEqual(ghostEndpointsLabelsFirst2, ghostEndpointsLabelsSecond[1].text, "The ghost Widget has change the endpoints label in the second access to Wiring Editor")
 
@@ -778,8 +872,10 @@ class WiringGhostTestCase(WirecloudSeleniumTestCase):
 
         iwidgets = self.get_current_iwidgets()
         self.assertEqual(len(iwidgets), 2)
+
+        self.assertTrue('error' in self.driver.find_element_by_css_selector("#wirecloud_header .menu .wiring").get_attribute('class'))
         self.change_main_view('wiring')
-        time.sleep(2)
+
         ghostWidget = self.driver.find_elements_by_css_selector('.grid > .iwidget.ghost')
         self.assertEqual(len(ghostWidget), 1)
         # 5 connections
@@ -859,16 +955,13 @@ class WiringGhostTestCase(WirecloudSeleniumTestCase):
         iwidgets = self.get_current_iwidgets()
         self.assertEqual(len(iwidgets), 2)
         self.change_main_view('wiring')
-        time.sleep(2)
         ghostWidget = self.driver.find_elements_by_css_selector('.grid > .ioperator.ghost')
         ghostEndpointsLabelsFirst1 = self.driver.find_elements_by_css_selector('.grid > .ioperator.ghost .labelDiv')[0].text
         ghostEndpointsLabelsFirst2 = self.driver.find_elements_by_css_selector('.grid > .ioperator.ghost .labelDiv')[1].text
         # Ghost
         self.assertEqual(len(ghostWidget), 1, "The ghost Operator has not been painted in the first access to Wiring Editor")
         self.change_main_view('workspace')
-        time.sleep(2)
         self.change_main_view('wiring')
-        time.sleep(2)
         ghostOperator = self.driver.find_elements_by_css_selector('.grid > .ioperator.ghost')
         self.assertEqual(len(ghostOperator), 1, "The ghost Operator has not been painted in the second access to Wiring Editor")
         ghostEndpointsLabelsSecond = self.driver.find_elements_by_css_selector('.grid > .ioperator.ghost .labelDiv')
@@ -1009,8 +1102,10 @@ class WiringGhostTestCase(WirecloudSeleniumTestCase):
 
         iwidgets = self.get_current_iwidgets()
         self.assertEqual(len(iwidgets), 2)
+
+        self.assertTrue('error' in self.driver.find_element_by_css_selector("#wirecloud_header .menu .wiring").get_attribute('class'))
         self.change_main_view('wiring')
-        time.sleep(2)
+
         ghostOperator = self.driver.find_elements_by_css_selector('.grid > .ioperator.ghost')
         self.assertEqual(len(ghostOperator), 1)
         # 5 connections
@@ -1097,7 +1192,6 @@ class WiringGhostTestCase(WirecloudSeleniumTestCase):
         iwidgets = self.get_current_iwidgets()
         self.assertEqual(len(iwidgets), 2)
         self.change_main_view('wiring')
-        time.sleep(2)
         arrows = self.driver.find_elements_by_css_selector('.arrow')
         self.assertEqual(len(arrows), 2)
         # The find_element_by_css_selector is needed to work around a bug in the firefox driver
@@ -1185,7 +1279,6 @@ class WiringGhostTestCase(WirecloudSeleniumTestCase):
         iwidgets = self.get_current_iwidgets()
         self.assertEqual(len(iwidgets), 2)
         self.change_main_view('wiring')
-        time.sleep(2)
         widget = self.driver.find_elements_by_css_selector('.grid > .iwidget')[0]
         operator = self.driver.find_elements_by_css_selector('.grid > .ioperator')[0]
         widget.click()
@@ -1201,15 +1294,16 @@ class WiringGhostTestCase(WirecloudSeleniumTestCase):
 class EndpointOrderTestCase(WirecloudSeleniumTestCase):
 
     fixtures = ('initial_data', 'selenium_test_data', 'user_with_workspaces')
+    tags = ('wiring', 'wiring_editor')
 
     @classmethod
     def setUpClass(cls):
 
         super(EndpointOrderTestCase, cls).setUpClass()
 
-        if cls.driver.capabilities['browserName'] == 'firefox' and not cls.driver.profile.native_events_enabled:
+        if not selenium_supports_draganddrop(cls.driver):
             cls.tearDownClass()
-            raise unittest.SkipTest('Endpoint reordering tests need make use of the native events support when using FirefoxDriver (not available on Mac OS)')
+            raise unittest.SkipTest('Endpoint reordering tests need make use of the native events support on selenium <= 2.37.2 when using FirefoxDriver (not available on Mac OS)')
 
     @uses_extra_resources(('Wirecloud_TestMultiendpoint_1.0.wgt',), shared=True)
     def test_wiring_widget_reorder_endpoints(self):
@@ -1218,7 +1312,6 @@ class EndpointOrderTestCase(WirecloudSeleniumTestCase):
 
         iwidget = self.add_widget_to_mashup('Test_Multiendpoint', new_name='Test (1)')
         self.change_main_view('wiring')
-        time.sleep(2)
 
         grid = self.driver.find_element_by_xpath("//*[contains(@class, 'container center_container grid')]")
         miniwidget = self.driver.find_element_by_xpath("//*[contains(@class, 'container iwidget')]//*[text()='Test (1)']")
@@ -1261,7 +1354,6 @@ class EndpointOrderTestCase(WirecloudSeleniumTestCase):
         self.login()
 
         self.change_main_view('wiring')
-        time.sleep(2)
 
         grid = self.driver.find_element_by_xpath("//*[contains(@class, 'container center_container grid')]")
 
@@ -1294,7 +1386,6 @@ class EndpointOrderTestCase(WirecloudSeleniumTestCase):
         self.change_main_view('workspace')
         time.sleep(0.3) # We need to wait for the wiring status been saved
         self.change_main_view('wiring')
-        time.sleep(2)
 
         self.assertEqual(ioperator.get_wiring_endpoint('output1').pos, 2)
         self.assertEqual(ioperator.get_wiring_endpoint('output2').pos, 0)
@@ -1305,15 +1396,16 @@ class EndpointOrderTestCase(WirecloudSeleniumTestCase):
 class MulticonnectorTestCase(WirecloudSeleniumTestCase):
 
     fixtures = ('initial_data', 'selenium_test_data', 'user_with_workspaces')
+    tags = ('wiring', 'wiring_editor')
 
     @classmethod
     def setUpClass(cls):
 
         super(MulticonnectorTestCase, cls).setUpClass()
 
-        if cls.driver.capabilities['browserName'] == 'firefox' and not cls.driver.profile.native_events_enabled:
+        if not selenium_supports_draganddrop(cls.driver):
             cls.tearDownClass()
-            raise unittest.SkipTest('Multiconnector tests need make use of the native events support when using FirefoxDriver (not available on Mac OS)')
+            raise unittest.SkipTest('Multiconnector tests need make use of the native events support on selenium <= 2.37.2 when using FirefoxDriver (not available on Mac OS)')
 
     def test_wiring_basic_multiconnector_visualization(self):
 
@@ -1322,7 +1414,6 @@ class MulticonnectorTestCase(WirecloudSeleniumTestCase):
         iwidget = self.add_widget_to_mashup('Test', new_name='Test (1)')
 
         self.change_main_view('wiring')
-        time.sleep(2)
         grid = self.driver.find_element_by_xpath("//*[contains(@class, 'container center_container grid')]")
 
         source = self.driver.find_element_by_xpath("//*[contains(@class, 'container iwidget')]//*[text()='Test (1)']")
@@ -1362,7 +1453,6 @@ class MulticonnectorTestCase(WirecloudSeleniumTestCase):
         iwidgets = self.get_current_iwidgets()
 
         self.change_main_view('wiring')
-        time.sleep(2)
         grid = self.driver.find_element_by_xpath("//*[contains(@class, 'container center_container grid')]")
 
         source = self.driver.find_element_by_xpath("//*[contains(@class, 'container iwidget')]//*[text()='Test (1)']")
@@ -1385,7 +1475,6 @@ class MulticonnectorTestCase(WirecloudSeleniumTestCase):
         ActionChains(self.driver).drag_and_drop(target2.element, multi).perform()
 
         self.change_main_view('workspace')
-        time.sleep(0.2)
 
         with iwidgets[0]:
             text_input = self.driver.find_element_by_tag_name('input')
@@ -1423,7 +1512,6 @@ class MulticonnectorTestCase(WirecloudSeleniumTestCase):
 
         iwidgets = self.get_current_iwidgets()
         self.change_main_view('wiring')
-        time.sleep(2)
         grid = self.driver.find_element_by_xpath("//*[contains(@class, 'container center_container grid')]")
 
         source = self.driver.find_element_by_xpath("//*[contains(@class, 'container iwidget')]//*[text()='Test (1)']")
@@ -1446,7 +1534,6 @@ class MulticonnectorTestCase(WirecloudSeleniumTestCase):
         ActionChains(self.driver).drag_and_drop(source2.element, multi).perform()
 
         self.change_main_view('workspace')
-        time.sleep(0.2)
 
         with iwidgets[1]:
             text_input = self.driver.find_element_by_tag_name('input')
@@ -1495,9 +1582,9 @@ class StickyEffectTestCase(WirecloudSeleniumTestCase):
 
         super(StickyEffectTestCase, cls).setUpClass()
 
-        if cls.driver.capabilities['browserName'] == 'firefox' and not cls.driver.profile.native_events_enabled:
+        if not selenium_supports_draganddrop(cls.driver):
             cls.tearDownClass()
-            raise unittest.SkipTest('Sticky effect tests need make use of the native events support when using FirefoxDriver (not available on Mac OS)')
+            raise unittest.SkipTest('Sticky effect tests need make use of the native events support on selenium <= 2.37.2 when using FirefoxDriver (not available on Mac OS)')
 
     def test_wiring_stycky_effect_in_endpoint_label(self):
         self.login()
@@ -1505,7 +1592,6 @@ class StickyEffectTestCase(WirecloudSeleniumTestCase):
         self.add_widget_to_mashup('Test', new_name='Test (1)')
         iwidgets = self.get_current_iwidgets()
         self.change_main_view('wiring')
-        time.sleep(2)
         grid = self.driver.find_element_by_xpath("//*[contains(@class, 'container center_container grid')]")
 
         widget = self.driver.find_element_by_xpath("//*[contains(@class, 'container iwidget')]//*[text()='Test (1)']")
@@ -1530,7 +1616,6 @@ class StickyEffectTestCase(WirecloudSeleniumTestCase):
         ActionChains(self.driver).drag_and_drop(operatorOutput.element, widgetInput.label).perform()
 
         self.change_main_view('workspace')
-        time.sleep(0.2)
 
         with iwidgets[0]:
             text_input = self.driver.find_element_by_tag_name('input')
@@ -1553,9 +1638,9 @@ class SimpleRecommendationsTestCase(WirecloudSeleniumTestCase):
 
         super(SimpleRecommendationsTestCase, cls).setUpClass()
 
-        if cls.driver.capabilities['browserName'] == 'firefox' and not cls.driver.profile.native_events_enabled:
+        if not selenium_supports_draganddrop(cls.driver):
             cls.tearDownClass()
-            raise unittest.SkipTest('Simple recommendation tests need make use of the native events support when using FirefoxDriver (not available on Mac OS)')
+            raise unittest.SkipTest('Simple recommendation tests need make use of the native events support on selenium <= 2.37.2 when using FirefoxDriver (not available on Mac OS)')
 
     def test_wiring_recommendations_basic_mouseon(self):
         self.login()
@@ -1566,7 +1651,6 @@ class SimpleRecommendationsTestCase(WirecloudSeleniumTestCase):
 
         iwidgets = self.get_current_iwidgets()
         self.change_main_view('wiring')
-        time.sleep(2)
         grid = self.driver.find_element_by_xpath("//*[contains(@class, 'container center_container grid')]")
 
         source = self.driver.find_element_by_xpath("//*[contains(@class, 'container iwidget')]//*[text()='Test (1)']")
@@ -1625,7 +1709,6 @@ class SimpleRecommendationsTestCase(WirecloudSeleniumTestCase):
 
         iwidgets = self.get_current_iwidgets()
         self.change_main_view('wiring')
-        time.sleep(2)
         grid = self.driver.find_element_by_xpath("//*[contains(@class, 'container center_container grid')]")
 
         source = self.driver.find_element_by_xpath("//*[contains(@class, 'container iwidget')]//*[text()='Test (1)']")
